@@ -2,13 +2,11 @@
 switchboard.builtins
 ~~~~~~~~~~~~~~~
 
-:copyright: (c) 2012 SourceForge.
+:copyright: (c) 2015 Kyle Adams.
 :license: Apache License 2.0, see LICENSE for more details.
 """
 import socket
 
-from formencode import validators
-
 from . import operator
 from .conditions import (
     RequestConditionSet,
@@ -17,13 +15,23 @@ from .conditions import (
     Boolean,
     Regex,
     ConditionSet,
+    Invalid,
 )
 from .settings import settings
 
 
 class IPAddress(String):
     def clean(self, value):
-        validators.IPAddress().to_python(value)
+        # Attempt to validate if the proper library is present.
+        try:
+            import ipaddress
+            # The third-party ipaddress lib (not the builtin Python 3 library)
+            # requires a unicode string.
+            ipaddress.ip_address(str(value))
+        except ImportError:  # pragma: nocover
+            pass
+        except ValueError:
+            raise Invalid
         return value
 
 
@@ -39,17 +47,18 @@ class IPAddressConditionSet(RequestConditionSet):
         # XXX: can we come up w/ a better API?
         # Ensure we map ``percent`` to the ``id`` column
         if field_name == 'percent':
-            return sum([int(x) for x in instance.remote_addr.split('.')])
+            return sum(int(x) for x in instance.remote_addr.split('.'))
         elif field_name == 'ip_address':
             return instance.remote_addr
         elif field_name == 'internal_ip':
             return instance.remote_addr in settings.SWITCHBOARD_INTERNAL_IPS
-        return super(IPAddressConditionSet, self).get_field_value(instance,
+        return super().get_field_value(instance,
                                                                   field_name)
 
-    def get_group_label(self):
+    def get_group_label(self):  # pragma: nocover
         return 'IP Address'
 
+
 operator.register(IPAddressConditionSet())
 
 
@@ -65,6 +74,7 @@ class QueryStringConditionSet(RequestConditionSet):
     def get_group_label(self):
         return 'Query String'
 
+
 operator.register(QueryStringConditionSet())
 
 
@@ -84,4 +94,5 @@ class HostConditionSet(ConditionSet):
     def get_group_label(self):
         return 'Host'
 
+
 operator.register(HostConditionSet())
