@@ -2,11 +2,11 @@
 switchboard.proxy
 ~~~~~~~~~~~~~
 
-:copyright: (c) 2012 SourceForge.
+:copyright: (c) 2015 Kyle Adams.
 :license: Apache License 2.0, see LICENSE for more details.
 """
 
-class SwitchProxy(object):
+class SwitchProxy:
     def __init__(self, manager, switch):
         self._switch = switch
         self._manager = manager
