@@ -2,26 +2,27 @@
 switchboard.settings
 ~~~~~~~~~~~~~
 
-:copyright: (c) 2012 Sourceforge.
+:copyright: (c) 2015 Kyle Adams.
 :license: Apache License 2.0, see LICENSE for more details.
 """
 
 NoValue = object()
 
 
-class Settings(object):
+class Settings:
 
     _state = {}
 
     @classmethod
-    def init(cls, mongo_host='localhost', mongo_port=27017,
+    def init(cls, cache=None, mongo_host='localhost', mongo_port=27017,
              mongo_db='switchboard', mongo_collection='switches',
              **kwargs):
         cls._state['SWITCHBOARD_MONGO_HOST'] = mongo_host
         cls._state['SWITCHBOARD_MONGO_PORT'] = mongo_port
         cls._state['SWITCHBOARD_MONGO_DB'] = mongo_db
         cls._state['SWITCHBOARD_MONGO_COLLECTION'] = mongo_collection
-        remainder = kwargs.iteritems()
+        cls._state['SWITCHBOARD_CACHE'] = cache
+        remainder = kwargs.items()
         remainder = [('SWITCHBOARD_%s' % k.upper(), v) for k, v in remainder]
         # convert timeouts to ints
         remainder = [(k, int(v) if k.endswith('TIMEOUT') else v)
@@ -42,4 +43,4 @@ class Settings(object):
         self._state[name] = value
 
 
-settings = Settings.init()
+settings = Settings.init()
\ No newline at end of file
