@@ -30,7 +30,7 @@ from ..settings import settings
 
 
 class TestAPI:
-    def setup(self):
+    def setup_method(self):
         settings.SWITCHBOARD_SWITCH_DEFAULTS = {
             'active_by_default': {
                 'is_active': True,
@@ -48,7 +48,7 @@ class TestAPI:
         self.operator.register(IPAddressConditionSet)
         self.operator.register(HostConditionSet)
 
-    def teardown(self):
+    def teardown_method(self):
         Switch.c.drop()
 
     def test_builtin_registration(self):
@@ -60,7 +60,7 @@ class TestAPI:
     def test_unregister(self):
         self.operator.unregister(QueryStringConditionSet)
         condition_set_id = 'switchboard.builtins.QueryStringConditionSet'
-        assert not condition_set_id in registry
+        assert condition_set_id not in registry
         assert len(list(self.operator.get_condition_sets())) == 2, self.operator
 
     def test_get_all_conditions(self):
@@ -261,7 +261,7 @@ class TestAPI:
 
         switch.delete()
 
-        assert not 'test' in self.operator
+        assert 'test' not in self.operator
 
     def test_expiration(self):
         switch = Switch.create(key='test')
@@ -737,7 +737,7 @@ class TestAPI:
 
 
 class TestConfigure:
-    def setup(self):
+    def setup_method(self):
         self.config = dict(
             mongo_host='mongodb',
             mongo_port=8080,
@@ -750,7 +750,7 @@ class TestConfigure:
             cache_hosts=['127.0.0.1']
         )
 
-    def teardown(self):
+    def teardown_method(self):
         Switch.c = MockCollection()
 
     def assert_settings(self):
@@ -790,7 +790,7 @@ class TestConfigure:
 
 class TestManagerConcurrency:
 
-    def setup(self):
+    def setup_method(self):
         self.operator = SwitchManager(auto_create=True)
         self.exc = None
 
@@ -804,7 +804,7 @@ class TestManagerConcurrency:
 
         def verify_context():
             try:
-                assert self.operator.context.get('foo') == None
+                assert self.operator.context.get('foo') is None
             except Exception as e:
                 self.exc = e
 
@@ -821,7 +821,7 @@ class TestManagerConcurrency:
 
 class TestManagerResultCaching:
 
-    def setup(self):
+    def setup_method(self):
         self.operator = SwitchManager(auto_create=True)
         self.operator.result_cache = {}
 
@@ -849,7 +849,7 @@ class TestManagerResultCaching:
 
 class TestManagerResultCacheDecorator:
 
-    def setup(self):
+    def setup_method(self):
         # Gets a pure function, otherwise we get an unbound function that we
         # can't call.
         self.with_result_cache = SwitchManager.__dict__['with_result_cache']
@@ -865,7 +865,7 @@ class TestManagerResultCacheDecorator:
         operator_self = Mock(result_cache=None)
         result = self.cached_is_active_func(operator_self, 'mykey')
         assert result
-        assert operator_self.result_cache == None
+        assert operator_self.result_cache is None
 
     def test_decorator_simple(self):
         operator_self = Mock(result_cache={})
@@ -906,7 +906,7 @@ class TestManagerResultCacheDecorator:
 
 
 class TestManagerConstants:
-    def setup(self):
+    def setup_method(self):
         self.operator = SwitchManager()
 
     def test_disabled(self):
