@@ -23,10 +23,10 @@ from ..settings import settings
 
 
 class TestMongoModel:
-    def setup(self):
+    def setup_method(self):
         self.m = MongoModel()
 
-    def teardown(self):
+    def teardown_method(self):
         MongoModel.c.drop()
 
     @patch('switchboard.models.MongoModel.update')
@@ -50,10 +50,10 @@ class TestMongoModel:
 
 
 class TestVersioningMongoModel:
-    def setup(self):
+    def setup_method(self):
         self.m = VersioningMongoModel(_id='0')
 
-    def teardown(self):
+    def teardown_method(self):
         VersioningMongoModel._versioned_collection().drop()
 
     def test_diff_fields_added(self):
@@ -150,7 +150,7 @@ class TestVersioningMongoModel:
 
 
 class TestConstant:
-    def setup(self):
+    def setup_method(self):
         self.operator = SwitchManager()
 
     def test_disabled(self):
@@ -175,7 +175,7 @@ class TestConstant:
 
 
 class TestSwitch:
-    def setup(self):
+    def setup_method(self):
         self.condition_set = IPAddressConditionSet()
         self.manager = SwitchManager(auto_create=True)
         self.manager.register(self.condition_set)
@@ -191,7 +191,7 @@ class TestSwitch:
             ],
         }
 
-    def teardown(self):
+    def teardown_method(self):
         Switch.c.drop()
         Switch._versioned_collection().drop()
 
@@ -323,7 +323,7 @@ class TestSwitch:
             condition='127.0.0.1',
         )
         assert self.condition_set.get_namespace() in self.switch.value
-        assert not 'ip_address' in self.switch.value[namespace]
+        assert 'ip_address' not in self.switch.value[namespace]
         assert (self.switch.value[namespace]['percent'] ==
                       [[INCLUDE, '0-50']])
         assert save.call_count == 3
@@ -333,7 +333,7 @@ class TestSwitch:
             field_name='percent',
             condition='0-50',
         )
-        assert not self.condition_set.get_namespace() in self.switch.value
+        assert self.condition_set.get_namespace() not in self.switch.value
         assert save.call_count == 4
 
     @patch('switchboard.models.Switch.save')
@@ -388,7 +388,7 @@ class TestSwitch:
         self.switch.clear_conditions(self.manager, self.condition_set.get_id(),
                                      field_name='ip_address')
         namespace = self.condition_set.get_namespace()
-        assert not 'ip_address' in self.switch.value[namespace]
+        assert 'ip_address' not in self.switch.value[namespace]
         assert (self.switch.value[namespace]['percent'] ==
                       [[INCLUDE, '0-50']])
         assert save.called
@@ -396,14 +396,14 @@ class TestSwitch:
     @patch('switchboard.models.Switch.save')
     def test_clear_conditions_whole_namespace(self, save):
         self.switch.clear_conditions(self.manager, self.condition_set.get_id())
-        assert not self.condition_set.get_namespace() in self.switch.value
+        assert self.condition_set.get_namespace() not in self.switch.value
         assert save.called
 
     @patch('switchboard.models.Switch.save')
     def test_clear_conditions_no_commit(self, save):
         set_id = self.condition_set.get_id()
         self.switch.clear_conditions(self.manager, set_id, commit=False)
-        assert not self.condition_set.get_namespace() in self.switch.value
+        assert self.condition_set.get_namespace() not in self.switch.value
         assert not save.called
 
     def test_get_active_conditions(self):
